using System;
using System.Collections.Generic;
using System.Text;

using Spire.Xls;
using Spire.Xls.Collections;
using Spire.Xls.Core;

namespace SimplePivotTable
{
    class Program
    {
        static void Main(string[] args)
        {
            Workbook workbook = new Workbook();
            //Load data to workbook
            workbook.LoadFromFile(@"..\..\orders.xls");
            //Get worksheet of data
            Worksheet data = workbook.Worksheets[0];
            //Get worksheet of pivot table 
            Worksheet report = workbook.Worksheets.Add("report");
            //Add pivot cache
            PivotCache pc = workbook.PivotCaches.Add(data["A1:L206"]);
            PivotTable pt = report.PivotTables.Add("order_report", report.Range["B2"], pc);

            IPivotField fieldOrderNo = pt.Fields["OrderNo"];
            fieldOrderNo.Axis = AxisTypes.Row;

            IPivotField fieldShipVIA = pt.Fields["ShipVIA"];
            fieldShipVIA.Axis = AxisTypes.Column;

            IPivotField fieldItemsTotal = pt.Fields["ItemsTotal"];
            pt.DataFields.Add(fieldItemsTotal, "ItemsTotal", SubtotalTypes.Sum);

            //Show expand/collapse button.
            pt.ShowDrillIndicators = true;

            //Shows row grand.
            pt.RowGrand = true;

            //Shows filter and field caption.
            pt.DisplayFieldCaptions = true;

            pt.BuiltInStyle = PivotBuiltInStyles.PivotStyleDark14;

            report.Activate();


            String name = String.Format("{0}.xlsx", Guid.NewGuid());
            workbook.SaveToFile(name, ExcelVersion.Version2007);
            System.Diagnostics.Process.Start(name);
        }
    }
}
